polar2grid.readers.viirs\_edr\_active\_fires module
===================================================

.. automodule:: polar2grid.readers.viirs_edr_active_fires
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:
